package db;

 import java.util.*;
 import java.sql.*;
 
 
public class DbTrans
{
    private DbConnection m_conn;
    /*
     *	Start a new transaction
     */
    public DbTrans() 
    {
	m_conn = DbConnection.pop();
    }


    /*
     *  Get a statement
     */
    public final PreparedStatement getStatement(
	    final String name,					
	    final String sql)
    {
	return m_conn.getStatement(name, sql);
    }

    /*
     *  Get the raw jdbc connection object
     */
    public final Connection getConnection()
    {
	return m_conn.getJdbcConnection();
    }

    /*
     *  mode for close()/chain()
     */
    public static final int COMMIT = 0;
    public static final int ROLLBACK = 1;

    /*
     *  Chain the transaction. 
     */
    public final void chain(int mode)
    {
	try {
	    if (mode == COMMIT)
		m_conn.getJdbcConnection().commit();
	    else
		m_conn.getJdbcConnection().rollback();
	}
	catch (Exception e) {
	    fatal("cannot chain transaction", e);
	}
    }
	    

    /*
     *	Close the transaction. Either commit or rollback.
     */
    public final void close(int closeMode)
    {
	try {
	    if (closeMode == COMMIT)
		m_conn.getJdbcConnection().commit();
	    else 
		m_conn.getJdbcConnection().rollback();
		
	    DbConnection.push(m_conn);
	    m_conn = null;
	}
	catch (Exception e) {
	    fatal("cannot close transaction", e);
	}
    }

    /*
     *  Fatal error
     */
    private static final void fatal(final String msg, final Exception e)
    {
	System.err.println(msg);
	System.err.println(e);
	if (e instanceof SQLException) {
	    SQLException s = (SQLException) e;
	    System.err.println("sql error code  : " + s.getErrorCode());
	    System.err.println("sql error state : " + s.getSQLState());
	}
	System.err.println("exit 44");
	System.exit(44);
    }



}
