package db;

import java.util.*;
import java.sql.*;

public class Test
{

    public static void main(String[] arg)
	throws Throwable
    {
	if (arg.length != 4) {
	    System.err.println("usage: db.Test user passwd url driver");
	    System.err.println();
	    System.err.println("  e.g. db.Test db2inst1 db2admin "
			       + "jdbc:db2:dev1 "
			       + "COM.ibm.db2.jdbc.app.DB2Driver");
	    System.err.println();
	    System.err.println("  e.g. db.Test dev1 dev1 "
			       + "jdbc:oracle:thin:@dbhost:1521:SAMPLEDB "
			       + "oracle.jdbc.driver.OracleDriver");
	    System.exit(1);
	}

	try {
	    DbConnection.init(5, arg[0], arg[1], arg[2], arg[3]);
	}
	catch (Exception e) {
	    System.err.println("failed to connect: " + e);
	    System.exit(1);
	}


	boolean commit = false;
	DbTrans trans = new DbTrans();
	try {
	    Calendar c = Calendar.getInstance();
	    c.clear();
	    c.set(2000, 0, 1);
	    InsertEmployee.execute(trans, 1000, 
				   "John Smith", 100000, 
				   new Timestamp(c.getTime().getTime()));
	    System.out.println("inserted 1000 John Smith 100000");

	    UpdateEmployeeSalaryById.execute(trans, 120000, 1000);
	    System.out.println("updated 1000 120000");

	    SelectEmployeeById.Row row = 
		SelectEmployeeById.getOneRow(trans, 1000);
	    if (row != null) {
		System.out.println("selected " + row.id + " " 
				   + row.name  + " "
				   + row.salary + " "
				   + row.hireDate);
	    }
	    else {
		System.out.println("error: cannot find employee id 1000");
	    }

	    DeleteEmployeeById.execute(trans, 1000);
	    System.out.println("deleted 1000");

	    commit = true;
	}
	finally {
	    trans.close(commit ? trans.COMMIT : trans.ROLLBACK);
	}

	
	System.out.println("Statistics dump:");
	Statistic.dump(System.out);
    }
}
